// Export types
export type {
  ForwardingType,
  IForwardConfig,
  IForwardingHandler,
  ITargetConfig,
  IHttpOptions,
  IHttpsOptions,
  IAcmeForwardingOptions,
  ISecurityOptions,
  IAdvancedOptions
} from '../types/forwarding.types.js';

// Export values
export {
  ForwardingHandlerEvents,
  httpOnly,
  tlsTerminateToHttp,
  tlsTerminateToHttps,
  httpsPassthrough
} from '../types/forwarding.types.js';

// Export domain configuration
export * from './domain-config.js';

// Export handlers
export { ForwardingHandler } from './forwarding.handler.js';
export { HttpForwardingHandler } from './http.handler.js';
export { HttpsPassthroughHandler } from './https-passthrough.handler.js';
export { HttpsTerminateToHttpHandler } from './https-terminate-to-http.handler.js';
export { HttpsTerminateToHttpsHandler } from './https-terminate-to-https.handler.js';

// Export factory
export { ForwardingHandlerFactory } from './forwarding.factory.js';

// Export manager
export { DomainManager, DomainManagerEvents } from './domain-manager.js';

// Helper functions as a convenience object
import {
  httpOnly,
  tlsTerminateToHttp,
  tlsTerminateToHttps,
  httpsPassthrough
} from '../types/forwarding.types.js';

export const helpers = {
  httpOnly,
  tlsTerminateToHttp,
  tlsTerminateToHttps,
  httpsPassthrough
};